@@ -27,6 +27,19 @@ template<> struct pyopencvVecConverter<linemod::Template>
     }
 };
 
+template<> struct pyopencvVecConverter<linemod::Feature>
+{
+    static bool to(PyObject* obj, std::vector<linemod::Feature>& value, const ArgInfo info)
+    {
+        return pyopencv_to_generic_vec(obj, value, info);
+    }
+
+    static PyObject* from(const std::vector<linemod::Feature>& value)
+    {
+        return pyopencv_from_generic_vec(value);
+    }
+};
+
 template<> struct pyopencvVecConverter<Ptr<linemod::Modality> >
 {
     static bool to(PyObject* obj, std::vector<Ptr<linemod::Modality> >& value, const ArgInfo info)
@@ -42,5 +55,6 @@ template<> struct pyopencvVecConverter<Ptr<linemod::Modality> >
 
 typedef std::vector<linemod::Match> vector_Match;
 typedef std::vector<linemod::Template> vector_Template;
+typedef std::vector<linemod::Feature> vector_Feature;
 typedef std::vector<Ptr<linemod::Modality> > vector_Ptr_Modality;
 #endif
